( cd usr/bin ; rm -rf nnadmin )
( cd usr/bin ; ln -sf nn nnadmin )
( cd usr/bin ; rm -rf nnbatch )
( cd usr/bin ; ln -sf nn nnbatch )
( cd usr/bin ; rm -rf nncheck )
( cd usr/bin ; ln -sf nn nncheck )
( cd usr/bin ; rm -rf nngoback )
( cd usr/bin ; ln -sf nn nngoback )
( cd usr/bin ; rm -rf nngrep )
( cd usr/bin ; ln -sf nn nngrep )
( cd usr/bin ; rm -rf nnpost )
( cd usr/bin ; ln -sf nn nnpost )
( cd usr/bin ; rm -rf nntidy )
( cd usr/bin ; ln -sf nn nntidy )
